@@ -1,11 +1,12 @@
 
+from builtins import object
 import json
 import requests
 
 from .constants import K_NOTIF_API_URL
 
 
-class NotifApi:
+class NotifApi(object):
 
     def __init__(self, api_key):
         self.notif_service_url = K_NOTIF_API_URL
